@@ -9,12 +9,13 @@ import datetime
 import getpass
 import logging
 import os.path
+import socket
 import sys
 import time
 import threading
 import warnings
 
-from django.conf import settings
+from django.conf import settings as django_settings
 from django.contrib.auth.models import User
 from django.core import mail
 from django.core.handlers.wsgi import WSGIHandler
@@ -22,27 +23,60 @@ from django.core.management import call_command
 from django.core.urlresolvers import reverse
 from django.core.signals import got_request_exception
 from django.core.servers import basehttp
-from django.test import TestCase
+from django.test import TestCase, TransactionTestCase
 from django.template import TemplateSyntaxError
 from django.utils import simplejson
 from django.utils.encoding import smart_unicode
+from django.utils.functional import lazy
 
-from sentry import conf
-from sentry.helpers import transform, get_signature, get_auth_header
-from sentry.models import Message, GroupedMessage
 from sentry.client.base import SentryClient
 from sentry.client.handlers import SentryHandler
 from sentry.client.models import get_client
+from sentry.conf import settings
+from sentry.models import Message, GroupedMessage
+from sentry.utils import transform, get_signature, get_auth_header
+from sentry.utils.compat.db import connections
 
 from models import TestModel, DuplicateKeyModel
 
+# class NullHandler(logging.Handler):
+#     def emit(self, record):
+#         pass
+# 
+# # Configure our "oh shit" handler, so that we dont output a bunch of unused
+# # information to stderr
+# 
+# logger = logging.getLogger('sentry.error')
+# logger.addHandler(NullHandler())
+
+# Configure our test handler
+
 logger = logging.getLogger('sentry.test')
 logger.addHandler(SentryHandler())
+logger.setLevel(logging.DEBUG)
+
+class StoppableWSGIServer(basehttp.WSGIServer):
+    """WSGIServer with short timeout, so that server thread can stop this server."""
+
+    def server_bind(self):
+        """Sets timeout to 1 second."""
+        basehttp.WSGIServer.server_bind(self)
+        self.socket.settimeout(1)
+
+    def get_request(self):
+        """Checks for timeout when getting request."""
+        try:
+            sock, address = self.socket.accept()
+            sock.settimeout(None)
+            return (sock, address)
+        except socket.timeout:
+            raise
 
 class TestServerThread(threading.Thread):
     """Thread for running a http server while tests are running."""
 
-    def __init__(self, address, port):
+    def __init__(self, test, address, port):
+        self.test = test
         self.address = address
         self.port = port
         self._stopevent = threading.Event()
@@ -55,7 +89,7 @@ class TestServerThread(threading.Thread):
         try:
             handler = basehttp.AdminMediaHandler(WSGIHandler())
             server_address = (self.address, self.port)
-            httpd = basehttp.StoppableWSGIServer(server_address, basehttp.WSGIRequestHandler)
+            httpd = StoppableWSGIServer(server_address, basehttp.WSGIRequestHandler)
             httpd.set_app(handler)
             self.started.set()
         except basehttp.WSGIServerException, e:
@@ -64,13 +98,14 @@ class TestServerThread(threading.Thread):
             return
 
         # Must do database stuff in this new thread if database in memory.
-        if settings.DATABASE_ENGINE == 'sqlite3' \
-            and (not settings.TEST_DATABASE_NAME or settings.TEST_DATABASE_NAME == ':memory:'):
+        conn_settings = connections['default'].settings_dict
+        if conn_settings['ENGINE'] == 'sqlite3' \
+            and (not conn_settings['TEST_NAME'] or conn_settings['TEST_NAME'] == ':memory:'):
             # Import the fixture data into the test database.
-            if hasattr(self, 'fixtures'):
+            if hasattr(self.test, 'fixtures'):
                 # We have to use this slightly awkward syntax due to the fact
                 # that we're using *args and **kwargs together.
-                call_command('loaddata', *self.fixtures, **{'verbosity': 0})
+                call_command('loaddata', *self.test.fixtures, **{'verbosity': 0})
 
         # Loop until we get a stop event.
         while not self._stopevent.isSet():
@@ -98,7 +133,7 @@ class SentryTestCase(TestCase):
     urls = 'sentry.tests.urls'
 
     def setUp(self):
-        self._middleware = settings.MIDDLEWARE_CLASSES
+        self._middleware = django_settings.MIDDLEWARE_CLASSES
         self._handlers = None
         self._level = None
         self.logger = logging.getLogger('sentry')
@@ -108,7 +143,7 @@ class SentryTestCase(TestCase):
 
     def tearDown(self):
         self.tearDownHandler()
-        settings.MIDDLEWARE_CLASSES = self._middleware
+        django_settings.MIDDLEWARE_CLASSES = self._middleware
         
     def setUpHandler(self):
         self.tearDownHandler()
@@ -195,7 +230,7 @@ class SentryTestCase(TestCase):
         self.tearDownHandler()
 
     # def test404Middleware(self):
-    #     settings.MIDDLEWARE_CLASSES = settings.MIDDLEWARE_CLASSES + ('sentry.client.middleware.Sentry404CatchMiddleware',)
+    #     django_settings.MIDDLEWARE_CLASSES = django_settings.MIDDLEWARE_CLASSES + ('sentry.client.middleware.Sentry404CatchMiddleware',)
     #     
     #     response = self.client.get("/404/this-page-does-not-exist", REMOTE_ADDR="127.0.0.1:8000")
     #     self.assertTemplateUsed(response, '404.html')
@@ -245,7 +280,7 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.message, 'This is an error')
         
     def testAlternateDatabase(self):
-        conf.DATABASE_USING = 'default'
+        settings.DATABASE_USING = 'default'
         
         try:
             Message.objects.get(id=999999979)
@@ -262,7 +297,7 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.level, logging.ERROR)
         self.assertEquals(last.message, smart_unicode(exc))
 
-        conf.DATABASE_USING = None
+        settings.DATABASE_USING = None
     
     def testIncorrectUnicode(self):
         self.setUpHandler()
@@ -329,8 +364,8 @@ class SentryTestCase(TestCase):
         self.assertEquals(error.data['url'], 'a'*210)
     
     def testThrashing(self):
-        conf.THRASHING_LIMIT = 10
-        conf.THRASHING_TIMEOUT = 60
+        settings.THRASHING_LIMIT = 10
+        settings.THRASHING_TIMEOUT = 60
         
         Message.objects.all().delete()
         GroupedMessage.objects.all().delete()
@@ -346,7 +381,7 @@ class SentryTestCase(TestCase):
             this_message_id = get_client().create_from_text('hi')
             self.assertEquals(this_message_id, message_id)
         
-        self.assertEquals(Message.objects.count(), conf.THRASHING_LIMIT)
+        self.assertEquals(Message.objects.count(), settings.THRASHING_LIMIT)
     
     def testSignals(self):
         try:
@@ -381,8 +416,8 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.message, smart_unicode(exc))
 
     def testNoThrashing(self):
-        prev = conf.THRASHING_LIMIT
-        conf.THRASHING_LIMIT = 0
+        prev = settings.THRASHING_LIMIT
+        settings.THRASHING_LIMIT = 0
         
         Message.objects.all().delete()
         GroupedMessage.objects.all().delete()
@@ -392,7 +427,7 @@ class SentryTestCase(TestCase):
         
         self.assertEquals(Message.objects.count(), 50)
 
-        conf.THRASHING_LIMIT = prev
+        settings.THRASHING_LIMIT = prev
 
     def testDatabaseMessage(self):
         from django.db import connection
@@ -431,8 +466,8 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.view, 'sentry.tests.views.raise_exc')
 
     def testRequestMiddlwareException(self):
-        orig = list(settings.MIDDLEWARE_CLASSES)
-        settings.MIDDLEWARE_CLASSES = orig + ['sentry.tests.middleware.BrokenRequestMiddleware',]
+        orig = list(django_settings.MIDDLEWARE_CLASSES)
+        django_settings.MIDDLEWARE_CLASSES = orig + ['sentry.tests.middleware.BrokenRequestMiddleware',]
         
         self.assertRaises(ImportError, self.client.get, reverse('sentry'))
         self.assertEquals(Message.objects.count(), 1)
@@ -444,12 +479,12 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.message, 'request')
         self.assertEquals(last.view, 'sentry.tests.middleware.process_request')
         
-        settings.MIDDLEWARE_CLASSES = orig
+        django_settings.MIDDLEWARE_CLASSES = orig
 
     # XXX: Django doesn't handle response middleware exceptions (yet)
     # def testResponseMiddlwareException(self):
-    #     orig = list(settings.MIDDLEWARE_CLASSES)
-    #     settings.MIDDLEWARE_CLASSES = orig + ['sentry.tests.middleware.BrokenResponseMiddleware',]
+    #     orig = list(django_settings.MIDDLEWARE_CLASSES)
+    #     django_settings.MIDDLEWARE_CLASSES = orig + ['sentry.tests.middleware.BrokenResponseMiddleware',]
     #     
     #     self.assertRaises(ImportError, self.client.get, reverse('sentry'))
     #     self.assertEquals(Message.objects.count(), 1)
@@ -461,11 +496,11 @@ class SentryTestCase(TestCase):
     #     self.assertEquals(last.message, 'response')
     #     self.assertEquals(last.view, 'sentry.tests.middleware.process_response')
     #     
-    #     settings.MIDDLEWARE_CLASSES = orig
+    #     django_settings.MIDDLEWARE_CLASSES = orig
 
     def testViewMiddlewareException(self):
-        orig = list(settings.MIDDLEWARE_CLASSES)
-        settings.MIDDLEWARE_CLASSES = orig + ['sentry.tests.middleware.BrokenViewMiddleware',]
+        orig = list(django_settings.MIDDLEWARE_CLASSES)
+        django_settings.MIDDLEWARE_CLASSES = orig + ['sentry.tests.middleware.BrokenViewMiddleware',]
         
         self.assertRaises(ImportError, self.client.get, reverse('sentry'))
         self.assertEquals(Message.objects.count(), 1)
@@ -477,13 +512,13 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.message, 'view')
         self.assertEquals(last.view, 'sentry.tests.middleware.process_view')
         
-        settings.MIDDLEWARE_CLASSES = orig
+        django_settings.MIDDLEWARE_CLASSES = orig
 
     def testSettingName(self):
-        orig_name = conf.NAME
-        orig_site = conf.SITE
-        conf.NAME = 'foo'
-        conf.SITE = 'bar'
+        orig_name = settings.NAME
+        orig_site = settings.SITE
+        settings.NAME = 'foo'
+        settings.SITE = 'bar'
         
         self.assertRaises(Exception, self.client.get, reverse('sentry-raise-exc'))
 
@@ -498,8 +533,8 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.site, 'bar')
         self.assertEquals(last.view, 'sentry.tests.views.raise_exc')
         
-        conf.NAME = orig_name
-        conf.SITE = orig_site
+        settings.NAME = orig_name
+        settings.SITE = orig_site
 
     def testExclusionViewPath(self):
         try: Message.objects.get(pk=1341324)
@@ -510,7 +545,7 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.view, 'sentry.tests.tests.testExclusionViewPath')
 
     def testBestGuessView(self):
-        conf.EXCLUDE_PATHS = ['sentry.tests.tests']
+        settings.EXCLUDE_PATHS = ['sentry.tests.tests']
         
         try: Message.objects.get(pk=1341324)
         except: get_client().create_from_exception()
@@ -519,10 +554,10 @@ class SentryTestCase(TestCase):
         
         self.assertEquals(last.view, 'sentry.tests.tests.testBestGuessView')
         
-        conf.EXCLUDE_PATHS = []
+        settings.EXCLUDE_PATHS = []
 
     def testExcludeModulesView(self):
-        conf.EXCLUDE_PATHS = ['sentry.tests.views.decorated_raise_exc']
+        settings.EXCLUDE_PATHS = ['sentry.tests.views.decorated_raise_exc']
         
         self.assertRaises(Exception, self.client.get, reverse('sentry-raise-exc-decor'))
         
@@ -530,7 +565,7 @@ class SentryTestCase(TestCase):
         
         self.assertEquals(last.view, 'sentry.tests.views.raise_exc')
         
-        conf.EXCLUDE_PATHS = []
+        settings.EXCLUDE_PATHS = []
 
     def testVaryingMessages(self):
         self.assertRaises(Exception, self.client.get, reverse('sentry-raise-exc') + '?message=foo')
@@ -540,7 +575,7 @@ class SentryTestCase(TestCase):
         self.assertEquals(GroupedMessage.objects.count(), 1)
 
     def testIncludeModules(self):
-        conf.INCLUDE_PATHS = ['django.shortcuts.get_object_or_404']
+        settings.INCLUDE_PATHS = ['django.shortcuts.get_object_or_404']
         
         self.assertRaises(Exception, self.client.get, reverse('sentry-django-exc'))
         
@@ -548,7 +583,7 @@ class SentryTestCase(TestCase):
         
         self.assertEquals(last.view, 'django.shortcuts.get_object_or_404')
         
-        conf.INCLUDE_PATHS = []
+        settings.INCLUDE_PATHS = []
 
     def testTemplateNameAsView(self):
         self.assertRaises(TemplateSyntaxError, self.client.get, reverse('sentry-template-exc'))
@@ -647,11 +682,11 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.data['module'], 'sentry')
 
     def test404Middleware(self):
-        existing = settings.MIDDLEWARE_CLASSES
+        existing = django_settings.MIDDLEWARE_CLASSES
         
-        settings.MIDDLEWARE_CLASSES = (
+        django_settings.MIDDLEWARE_CLASSES = (
             'sentry.client.middleware.Sentry404CatchMiddleware',
-        ) + settings.MIDDLEWARE_CLASSES
+        ) + django_settings.MIDDLEWARE_CLASSES
         
         resp = self.client.get('/non-existant-page')
         self.assertEquals(resp.status_code, 404)
@@ -663,16 +698,16 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.level, logging.INFO)
         self.assertEquals(last.logger, 'http404')
 
-        settings.MIDDLEWARE_CLASSES = existing
+        django_settings.MIDDLEWARE_CLASSES = existing
 
     def testResponseErrorIdMiddleware(self):
         # TODO: test with 500s
-        existing = settings.MIDDLEWARE_CLASSES
+        existing = django_settings.MIDDLEWARE_CLASSES
         
-        settings.MIDDLEWARE_CLASSES = (
+        django_settings.MIDDLEWARE_CLASSES = (
             'sentry.client.middleware.SentryResponseErrorIdMiddleware',
             'sentry.client.middleware.Sentry404CatchMiddleware',
-        ) + settings.MIDDLEWARE_CLASSES
+        ) + django_settings.MIDDLEWARE_CLASSES
         
         resp = self.client.get('/non-existant-page')
         self.assertEquals(resp.status_code, 404)
@@ -680,13 +715,14 @@ class SentryTestCase(TestCase):
         self.assertTrue(headers.get('X-Sentry-ID'))
         self.assertTrue(Message.objects.filter(message_id=headers['X-Sentry-ID']).exists())
 
-        settings.MIDDLEWARE_CLASSES = existing
+        django_settings.MIDDLEWARE_CLASSES = existing
 
     def testExtraStorage(self):
-        from sentry.reporter import FakeRequest
+        from sentry.utils import MockDjangoRequest
         
-        request = FakeRequest()
-        request.META['foo'] = 'bar'
+        request = MockDjangoRequest(
+            META = {'foo': 'bar'},
+        )
         
         logger = logging.getLogger()
 
@@ -711,10 +747,11 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.data['baz'], 'bar')
 
     def testRawPostData(self):
-        from sentry.reporter import FakeRequest
+        from sentry.utils import MockDjangoRequest
         
-        request = FakeRequest()
-        request.raw_post_data = '{"json": "string"}'
+        request = MockDjangoRequest(
+            raw_post_data = '{"json": "string"}',
+        )
         
         logger = logging.getLogger()
 
@@ -798,10 +835,10 @@ class SentryViewsTest(TestCase):
     fixtures = ['sentry/tests/fixtures/views.json']
     
     def setUp(self):
-        conf.DATABASE_USING = None
+        settings.DATABASE_USING = None
         self._handlers = None
         self._level = None
-        conf.DEBUG = False
+        settings.DEBUG = False
         self.user = User(username="admin", email="admin@localhost", is_staff=True, is_superuser=True)
         self.user.set_password('admin')
         self.user.save()
@@ -857,32 +894,18 @@ class SentryViewsTest(TestCase):
         self.assertEquals(resp.status_code, 200, resp.content)
         self.assertTemplateUsed(resp, 'sentry/group/details.html')
 
-class RemoteSentryTest(TestCase):
+class SentryRemoteTest(TestCase):
     urls = 'sentry.tests.urls'
     
-    def start_test_server(self, address='localhost', port=8001):
-        """Creates a live test server object (instance of WSGIServer)."""
-        self.server_thread = TestServerThread(address, port)
-        self.server_thread.start()
-        self.server_thread.started.wait()
-        if self.server_thread.error:
-            raise self.server_thread.error
-
-    def stop_test_server(self):
-        if self.server_thread:
-            self.server_thread.join()
-    
     def setUp(self):
-        self.server_thread = None
-        conf.REMOTE_URL = ['http://localhost:8000%s' % reverse('sentry-store')]
+        settings.REMOTE_URL = ['http://localhost:8000%s' % reverse('sentry-store')]
         logger = logging.getLogger('sentry')
         for h in logger.handlers:
             logger.removeHandler(h)
         logger.addHandler(logging.StreamHandler())
 
     def tearDown(self):
-        self.stop_test_server()
-        conf.REMOTE_URL = None
+        settings.REMOTE_URL = None
 
     def testNoKey(self):
         resp = self.client.post(reverse('sentry-store'))
@@ -890,13 +913,13 @@ class RemoteSentryTest(TestCase):
 
     def testNoData(self):
         resp = self.client.post(reverse('sentry-store'), {
-            'key': conf.KEY,
+            'key': settings.KEY,
         })
         self.assertEquals(resp.status_code, 400)
 
     def testBadData(self):
         resp = self.client.post(reverse('sentry-store'), {
-            'key': conf.KEY,
+            'key': settings.KEY,
             'data': 'hello world',
         })
         self.assertEquals(resp.status_code, 403)
@@ -906,7 +929,7 @@ class RemoteSentryTest(TestCase):
         kwargs = {'message': 'hello', 'server_name': 'not_dcramer.local', 'level': 40, 'site': 'not_a_real_site'}
         resp = self.client.post(reverse('sentry-store'), {
             'data': base64.b64encode(pickle.dumps(transform(kwargs)).encode('zlib')),
-            'key': conf.KEY,
+            'key': settings.KEY,
         })
         self.assertEquals(resp.status_code, 200)
         instance = Message.objects.get()
@@ -919,7 +942,7 @@ class RemoteSentryTest(TestCase):
         kwargs = {u'message': 'hello', u'server_name': 'not_dcramer.local', u'level': 40, u'site': 'not_a_real_site'}
         resp = self.client.post(reverse('sentry-store'), {
             'data': base64.b64encode(pickle.dumps(transform(kwargs)).encode('zlib')),
-            'key': conf.KEY,
+            'key': settings.KEY,
         })
         self.assertEquals(resp.status_code, 200, resp.content)
         instance = Message.objects.get()
@@ -933,7 +956,7 @@ class RemoteSentryTest(TestCase):
         kwargs = {u'message': 'hello', 'timestamp': timestamp.strftime('%s.%f')}
         resp = self.client.post(reverse('sentry-store'), {
             'data': base64.b64encode(pickle.dumps(transform(kwargs)).encode('zlib')),
-            'key': conf.KEY,
+            'key': settings.KEY,
         })
         self.assertEquals(resp.status_code, 200, resp.content)
         instance = Message.objects.get()
@@ -947,7 +970,7 @@ class RemoteSentryTest(TestCase):
         kwargs = {'message': 'hello', 'server_name': 'not_dcramer.local', 'level': 40, 'site': 'not_a_real_site'}
         resp = self.client.post(reverse('sentry-store'), {
             'data': base64.b64encode(pickle.dumps(transform(kwargs))),
-            'key': conf.KEY,
+            'key': settings.KEY,
         })
         self.assertEquals(resp.status_code, 200)
         instance = Message.objects.get()
@@ -956,7 +979,6 @@ class RemoteSentryTest(TestCase):
         self.assertEquals(instance.site, 'not_a_real_site')
         self.assertEquals(instance.level, 40)
 
-
     def testByteSequence(self):
         """
         invalid byte sequence for encoding "UTF8": 0xedb7af
@@ -969,7 +991,7 @@ class RemoteSentryTest(TestCase):
         
         resp = self.client.post(reverse('sentry-store'), {
             'data': data,
-            'key': conf.KEY,
+            'key': settings.KEY,
         })
         self.assertEquals(resp.status_code, 200)
         instance = Message.objects.get()
@@ -984,7 +1006,7 @@ class RemoteSentryTest(TestCase):
         message = base64.b64encode(simplejson.dumps(transform(kwargs)))
         sig = get_signature(message, ts)
 
-        resp = self.client.post(reverse('sentry-store'), message, content_type='application/octet-stream', AUTHORIZATION=get_auth_header(sig, ts, 'foo'))
+        resp = self.client.post(reverse('sentry-store'), message, content_type='application/octet-stream', HTTP_AUTHORIZATION=get_auth_header(sig, ts, 'foo'))
         self.assertEquals(resp.status_code, 200, resp.content)
         instance = Message.objects.get()
         self.assertEquals(instance.message, 'hello')
@@ -1000,20 +1022,67 @@ class RemoteSentryTest(TestCase):
     #     
     #     self.assertEquals(last.view, 'sentry.tests.tests.testFunctionException')
 
-    # def testProcess(self):
-    #     self.start_test_server()
-    #     SentryClient().process(message='hello')
-    #     instance = Message.objects.all().order_by('-id')[0]
-    #     self.assertEquals(instance.message, 'hello')
-    #     self.stop_test_server()
-    # 
-    # def testExternal(self):
-    #     self.start_test_server()
-    #     self.assertRaises(Exception, self.client.get, '/?test')
-    #     instance = Message.objects.all().order_by('-id')[0]
-    #     self.assertEquals(instance.message, 'view exception')
-    #     self.assertEquals(instance.url, 'http://testserver/?test')
-    #     self.stop_test_server()
+class SentryRemoteServerTest(TransactionTestCase):
+    urls = 'sentry.tests.urls'
+    
+    def setUp(self):
+        self.server_thread = None
+        logger = logging.getLogger('sentry')
+        for h in logger.handlers:
+            logger.removeHandler(h)
+        logger.addHandler(logging.StreamHandler())
+
+    def tearDown(self):
+        self.stop_test_server()
+        settings.REMOTE_URL = None
+    
+    def start_test_server(self, host='localhost', port=None):
+        """Creates a live test server object (instance of WSGIServer)."""
+        if not port:
+            for port in xrange(8001, 65535):
+                s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+                s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+                try:
+                    s.bind((host, port))
+                except socket.error:
+                    port = None
+                    continue
+                else:
+                    break
+                finally:
+                    s.close()
+        if not port:
+            raise socket.error('Unable to find an open port to bind server')
+
+        self._orig_remote_url = settings.REMOTE_URL
+        settings.REMOTE_URL = ['http://%s:%s/store/' % (host, port)]
+        self.server_thread = TestServerThread(self, host, port)
+        self.server_thread.start()
+        self.server_thread.started.wait()
+        if self.server_thread.error:
+            raise self.server_thread.error
+
+    def stop_test_server(self):
+        if self.server_thread:
+            settings.REMOTE_URL = self._orig_remote_url
+            self.server_thread.join()
+
+    def testProcess(self):
+        self.start_test_server()
+        message_id = SentryClient().process(message='hello')
+        self.assertTrue(message_id)
+        instance = Message.objects.all().order_by('-id')[0]
+        self.assertEquals(instance.message, 'hello')
+        self.stop_test_server()
+
+    def testExternal(self):
+        self.start_test_server()
+        path = reverse('sentry-raise-exc')
+        self.assertRaises(Exception, self.client.get, path)
+        instance = Message.objects.all().order_by('-id')[0]
+        self.assertEquals(instance.message, 'view exception')
+        self.assertEquals(instance.url, 'http://testserver' + path)
+        self.stop_test_server()
 
 class SentryFeedsTest(TestCase):
     fixtures = ['sentry/tests/fixtures/feeds.json']
@@ -1042,7 +1111,7 @@ class SentryMailTest(TestCase):
     urls = 'sentry.tests.urls'
     
     def setUp(self):
-        conf.ADMINS = ('%s@localhost' % getpass.getuser(),)
+        settings.ADMINS = ('%s@localhost' % getpass.getuser(),)
     
     def test_mail_admins(self):
         group = GroupedMessage.objects.get()
@@ -1057,7 +1126,7 @@ class SentryMailTest(TestCase):
         self.assertEquals(out.subject, '[Django] Error (EXTERNAL IP): /group/1')
 
     def test_mail_on_creation(self):
-        conf.MAIL = True
+        settings.MAIL = True
         
         self.assertEquals(len(mail.outbox), 0)
         self.assertRaises(Exception, self.client.get, reverse('sentry-raise-exc'))
@@ -1072,7 +1141,7 @@ class SentryMailTest(TestCase):
         self.assertEquals(out.subject, '[example.com] [Django] Error (EXTERNAL IP): /trigger-500')
 
     def test_mail_on_duplication(self):
-        conf.MAIL = True
+        settings.MAIL = True
         
         self.assertEquals(len(mail.outbox), 0)
         self.assertRaises(Exception, self.client.get, reverse('sentry-raise-exc'))
@@ -1096,7 +1165,7 @@ class SentryMailTest(TestCase):
         self.assertEquals(out.subject, '[example.com] [Django] Error (EXTERNAL IP): /trigger-500')
 
     def test_url_prefix(self):
-        conf.URL_PREFIX = 'http://example.com'
+        settings.URL_PREFIX = 'http://example.com'
 
         group = GroupedMessage.objects.get()
         group.mail_admins(fail_silently=False)
@@ -1107,33 +1176,32 @@ class SentryMailTest(TestCase):
 
 class SentryHelpersTest(TestCase):
     def test_get_db_engine(self):
-        from sentry.helpers import get_db_engine
-        _databases = getattr(settings, 'DATABASES', {}).copy()
-        _engine = settings.DATABASE_ENGINE
+        from sentry.utils import get_db_engine
+        _databases = getattr(django_settings, 'DATABASES', {}).copy()
+        _engine = django_settings.DATABASE_ENGINE
         
-        settings.DATABASE_ENGINE = ''
-        settings.DATABASES['default'] = {'ENGINE': 'blah.sqlite3'}
+        django_settings.DATABASE_ENGINE = ''
+        django_settings.DATABASES['default'] = {'ENGINE': 'blah.sqlite3'}
         
         self.assertEquals(get_db_engine(), 'sqlite3')
 
-        settings.DATABASE_ENGINE = 'mysql'
+        django_settings.DATABASE_ENGINE = 'mysql'
 
         self.assertEquals(get_db_engine(), 'sqlite3')
 
-        settings.DATABASES['default'] = {'ENGINE': 'blah.mysql'}
+        django_settings.DATABASES['default'] = {'ENGINE': 'blah.mysql'}
 
         self.assertEquals(get_db_engine(), 'mysql')
         
-        settings.DATABASES = _databases
-        settings.DATABASE_ENGINE = _engine
+        django_settings.DATABASES = _databases
+        django_settings.DATABASE_ENGINE = _engine
 
     def test_transform_handles_gettext_lazy(self):
-        from sentry.helpers import transform
-        from django.utils.functional import lazy
-
         def fake_gettext(to_translate):
             return u'Igpay Atinlay'
+
         fake_gettext_lazy = lazy(fake_gettext, str)
+
         self.assertEquals(
             pickle.loads(pickle.dumps(
                     transform(fake_gettext_lazy("something")))),
@@ -1141,20 +1209,26 @@ class SentryHelpersTest(TestCase):
 
     def test_get_versions(self):
         import sentry
-        from sentry.helpers import get_versions
+        from sentry.utils import get_versions
         versions = get_versions(['sentry'])
         self.assertEquals(versions.get('sentry'), sentry.VERSION)
         versions = get_versions(['sentry.client'])
         self.assertEquals(versions.get('sentry'), sentry.VERSION)
 
+    def test_transform_model_instance(self):
+        instance = DuplicateKeyModel(foo='foo')
+        
+        result = transform(instance)
+        self.assertEquals(result, '<DuplicateKeyModel: foo>')
+
 class SentryClientTest(TestCase):
     urls = 'sentry.tests.urls'
 
     def setUp(self):
-        self._client = conf.CLIENT
+        self._client = settings.CLIENT
         
     def tearDown(self):
-        conf.CLIENT = self._client
+        settings.CLIENT = self._client
     
     def test_get_client(self):
         from sentry.client.log import LoggingSentryClient
@@ -1162,15 +1236,15 @@ class SentryClientTest(TestCase):
         self.assertEquals(get_client().__class__, SentryClient)
         self.assertEquals(get_client(), get_client())
     
-        conf.CLIENT = 'sentry.client.log.LoggingSentryClient'
+        settings.CLIENT = 'sentry.client.log.LoggingSentryClient'
         
         self.assertEquals(get_client().__class__, LoggingSentryClient)
         self.assertEquals(get_client(), get_client())
     
-        conf.CLIENT = 'sentry.client.base.SentryClient'
+        settings.CLIENT = 'sentry.client.base.SentryClient'
     
     def test_logging_client(self):
-        conf.CLIENT = 'sentry.client.log.LoggingSentryClient'
+        settings.CLIENT = 'sentry.client.log.LoggingSentryClient'
         
         client = get_client()
         
@@ -1196,7 +1270,7 @@ class SentryClientTest(TestCase):
         self.assertEquals(get_client().__class__, SentryClient)
         self.assertEquals(get_client(), get_client())
 
-        conf.CLIENT = 'sentry.client.celery.CelerySentryClient'
+        settings.CLIENT = 'sentry.client.celery.CelerySentryClient'
 
         self.assertEquals(get_client().__class__, CelerySentryClient)
         self.assertEquals(get_client(), get_client())
@@ -1207,7 +1281,7 @@ class SentryClientTest(TestCase):
         self.assertEqual(message.class_name, 'Exception')
         self.assertEqual(message.message, 'view exception')
 
-        conf.CLIENT = 'sentry.client.base.SentryClient'
+        settings.CLIENT = 'sentry.client.base.SentryClient'
 
     # XXX: need to fix behavior with threads so this test works correctly
     # def test_async_client(self):
@@ -1216,7 +1290,7 @@ class SentryClientTest(TestCase):
     #     self.assertEquals(get_client().__class__, SentryClient)
     #     self.assertEquals(get_client(), get_client())
     # 
-    #     conf.CLIENT = 'sentry.client.async.AsyncSentryClient'
+    #     settings.CLIENT = 'sentry.client.async.AsyncSentryClient'
     # 
     #     self.assertEquals(get_client().__class__, AsyncSentryClient)
     #     self.assertEquals(get_client(), get_client())
@@ -1227,18 +1301,17 @@ class SentryClientTest(TestCase):
     #     self.assertEqual(message.class_name, 'Exception')
     #     self.assertEqual(message.message, 'view exception')
     # 
-    #     conf.CLIENT = 'sentry.client.base.SentryClient'
+    #     settings.CLIENT = 'sentry.client.base.SentryClient'
 
-class SentryManageTest(TestCase):
+class SentryCommandTest(TestCase):
     fixtures = ['sentry/tests/fixtures/cleanup.json']
     
-    def test_cleanup_sentry(self):
-        from sentry.management.commands.cleanup_sentry import Command
+    def test_cleanup(self):
+        from sentry.scripts.runner import cleanup
         
         self.assertEquals(Message.objects.count(), 10)
         
-        command = Command()
-        command.handle(days=1)
+        cleanup(days=1)
         
         self.assertEquals(Message.objects.count(), 0)
 
@@ -1247,7 +1320,7 @@ class SentrySearchTest(TestCase):
 
     @conditional_on_module('haystack')
     def test_build_index(self):
-        from sentry.views import get_search_query_set
+        from sentry.web.views import get_search_query_set
         logger.error('test search error')
         
         qs = get_search_query_set('error')
